==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/sv.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generera återställningsnycklar",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Återställningsnycklarna har skapats. {{used}} av {{total}} nycklar har använts.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Detta är dina återställningsnycklar. Vänligen spara och/eller skriv ut dem eftersom du inte kommer kunna se dessa nycklar igen.",
    "Save backup codes" : "Spara återställningsnycklar",
    "Print backup codes" : "Skriv ut återställningsnycklar",
    "Regenerate backup codes" : "Skapa nya återställningsnycklar",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Om du skapar nya återställningsnycklar så kommer de gamla automatiskt att sluta fungera.",
    "An error occurred while generating your backup codes" : "Ett fel uppstod vid skapandet av nya återställningsnycklar",
    "Nextcloud backup codes" : "Nextcloud återställningsnycklar",
    "Two-factor authentication" : "Tvåfaktorsautentisering",
    "You successfully logged in using two-factor authentication (%1$s)" : "Du lyckades logga in genom att använda tvåfaktorsautentisering (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Ett inloggningsförsök med tvåfaktorsautentisering misslyckades (%1$s)",
    "You created two-factor backup codes for your account" : "Du skapade återställningsnycklar till tvåfaktorsautentiseringen på ditt användarkonto.",
    "Backup code" : "Återställningsnyckel",
    "Use backup code" : "Använd återställningsnyckel",
    "Second-factor backup codes" : "Tvåfaktorsautentisering"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/sv.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generera återställningsnycklar",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Återställningsnycklarna har skapats. {{used}} av {{total}} nycklar har använts.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Detta är dina återställningsnycklar. Vänligen spara och/eller skriv ut dem eftersom du inte kommer kunna se dessa nycklar igen.",
    "Save backup codes" : "Spara återställningsnycklar",
    "Print backup codes" : "Skriv ut återställningsnycklar",
    "Regenerate backup codes" : "Skapa nya återställningsnycklar",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Om du skapar nya återställningsnycklar så kommer de gamla automatiskt att sluta fungera.",
    "An error occurred while generating your backup codes" : "Ett fel uppstod vid skapandet av nya återställningsnycklar",
    "Nextcloud backup codes" : "Nextcloud återställningsnycklar",
    "You created two-factor backup codes for your account" : "Du skapade återställningsnycklar till tvåfaktorsautentiseringen på ditt användarkonto.",
    "Backup code" : "Återställningsnyckel",
    "Use backup code" : "Använd återställningsnyckel",
    "Two factor backup codes" : "Återställningsnycklar för Tvåfaktorautentisering",
    "Second-factor backup codes" : "Tvåfaktorsautentisering"
},
"nplurals=2; plural=(n != 1);");
